===============
Flask-Material-Lite
===============

An easy way to get started with Google\'s Material Lite in your next Flask project, without any boilerplate code.

Documentation and full source code availible at `https://github.com/HellerCommaA/flask-material-lite <https://github.com/HellerCommaA/flask-material-lite>`_.